<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package ama
 */

// Theme settings options.
$opt                    = get_option( 'ama_opt' );
$page_header_layout     = function_exists( 'get_field' ) ? get_field( 'header_layout' ) : '';
$header_type            = function_exists( 'get_field' ) ? get_field( 'ama_header_type' ) : 'default';
$is_sticky_header_doc   = function_exists( 'get_field' ) ? get_Field( 'is_sticky_header' ) : '';
$is_sticky_body_wrapper = '1' == $is_sticky_header_doc ? 'sticky_menu' : '';
$sticky_header_id       = '1' == $is_sticky_header_doc ? 'stickyTwo' : 'sticky';

$my_theme = wp_get_theme( 'ama' );
$s_value  = get_search_query() ? get_search_query() : '';
$class    = '';

$menu_class = 'black' == $header_type ? 'menu_black' : 'menu_white';
if ( is_search() ) {
	$menu_class = 'menu_white';
}

?>
	<!DOCTYPE html>
<html <?php language_attributes(); ?>>
	<head>
		<!-- Theme Version -->
		<meta name="ama-version" content="<?php echo esc_attr( $my_theme->Version ); ?>">
		<!-- Charset Meta -->
		<meta charset="<?php bloginfo( 'charset' ); ?>">
		<!-- For IE -->
		<meta http-equiv="X-UA-Compatible" content="IE=edge">
		<!-- For Resposive Device -->
		<meta name="viewport" content="width=device-width, initial-scale=1.0">

		<?php wp_head(); ?>
	</head>

<body <?php body_class(); ?> data-scroll-animation="true">
<?php
if ( function_exists( 'wp_body_open' ) ) {
	wp_body_open();
}

/**
 * Preloader
 */

$is_preloader = $opt['is_preloader'] ?? '';

if ( did_action( 'elementor/loaded' ) ) {
	if ( \Elementor\Plugin::$instance->preview->is_preview_mode() ) {
		$is_preloader = '';
	}
}

if ( '1' == $is_preloader ) {
	get_template_part( 'template-parts/header-elements/preloader' );
}
?>
<div class="body_wrapper <?php echo esc_attr( $is_sticky_body_wrapper ); ?>">
	<div class="click_capture"></div>
	<nav class="navbar navbar-expand-lg menu_one <?php echo esc_attr( $menu_class ); ?> sticky-nav d-lg-block d-none">
		<div class="container">
			<?php ama_helper()->logo(); ?>
			<div class="collapse navbar-collapse" id="navbarSupportedContent">
				<?php
				if ( has_nav_menu( 'main_menu' ) ) {
					wp_nav_menu(
						[
							'menu'           => 'main_menu',
							'theme_location' => 'main_menu',
							'container'      => null,
							'menu_class'     => 'navbar-nav menu ms-auto',
							'walker'         => new Ama_Nav_Walker(),
							'depth'          => 4,
						]
					);
				}
				?>
				<?php get_template_part( 'template-parts/header-elements/action-button' ); ?>
			</div>
		</div>
	</nav>
<?php
/**
 * Mobile menu
 */
get_template_part( 'template-parts/header-elements/mobile-menu' );

/**
 * Page Title-bar
 */
get_template_part( 'template-parts/header-elements/titlebar' );

/**
 * Single post Banner & Breadcrumb
 */
if ( is_single() && ! is_singular( [ 'forum', 'topic', 'docs' ] ) ) {
	get_template_part( 'template-parts/header-elements/banner-single' );
	get_template_part( 'template-parts/header-elements/breadcrumb' );
}

if ( '1' == ama_is_search_banner() && !is_singular( [ 'faq', 'video' ]) ) {
	get_template_part( 'template-parts/header-elements/search-banner/sbnr', ama_search_banner() );
}
