<?php
/**
 * Ama theme helper functions and resources
 */

class Ama_helper {
	/**
	 * Hold an instance of ama_helper class.
	 *
	 * @var ama_helper
	 */
	protected static $instance = null;

	/**
	 * Main ama_helper instance.
	 *
	 * @return ama_helper - Main instance.
	 */
	public static function instance() {

		if ( null == self::$instance ) {
			self::$instance = new ama_helper();
		}

		return self::$instance;
	}

	/**
	 * Website Logo
	 */
	public function logo() {
		$opt           = get_option( 'ama_opt' );
		$banner_preset = function_exists( 'get_field' ) ? get_field( 'banner_preset' ) : '';

		$select_main_logo = function_exists( 'get_field' ) ? get_field( 'ama_header_type' ) : '';
		$blog_name        = get_bloginfo( 'name' );

		// Main Logo.
		$main_logo   = $opt['main_logo'] ['url'] ?? '';
		$retina_logo = ! empty( $opt['retina_logo']['url'] ) ? "srcset='{$opt['retina_logo']['url']} 2x'" : '';

		// Sticky Logo.
		$sticky_logo        = $opt['sticky_logo']['url'] ?? '';
		$retina_sticky_logo = ! empty( $opt['retina_sticky_logo']['url'] ) ? "srcset='{$opt['retina_sticky_logo']['url']} 2x'" : '';

		$is_main_logo_white = '';
		$is_main_logo_black = '';

		if ( $select_main_logo == 'white' ) {
			$is_main_logo_white = $select_main_logo == 'white' ? 'main_logo' : '';
		} elseif ( $select_main_logo == 'black' ) {
			$is_main_logo_black = $select_main_logo == 'black' ? 'main_logo' : '';
		} elseif ( $select_main_logo == 'default' || ! isset( $select_main_logo ) ) {
			$is_main_logo_white = 'main_logo';
		}
		?>
		<a class="navbar-brand header_logo" href="<?php echo esc_url( home_url( '/' ) ); ?>">
			<?php if ( ! empty( $main_logo ) ) : ?>

				<?php
				 $first_logo = <<<FLOGO
                    <img class="first_logo sticky_logo {$is_main_logo_black}" src="{$main_logo}" alt="{$blog_name}" {$retina_logo}>
                FLOGO;

				 echo wp_kses( $first_logo, ama_allowed_html() );
				?>

				<?php
				if ( ! empty( $sticky_logo ) ) :
					$sticky_logo = <<<SLOGO
                <img class="white_logo {$is_main_logo_white}" src="{$sticky_logo}" alt="{$blog_name}" {$retina_sticky_logo}>
                SLOGO;

					echo wp_kses( $sticky_logo, ama_allowed_html() );
				endif;

			else :
				?>
				<h3> <?php echo get_bloginfo( 'name' ); ?> </h3>
				<?php
			endif;
			echo '</a>';
	}




	// Banner Title
	function banner_title() {
		$opt = get_option( 'ama_opt' );
		if ( is_home() ) {
			$blog_title = ! empty( $opt['blog_title'] ) ? $opt['blog_title'] : esc_html__( 'Blog', 'ama' );
			echo esc_html( $blog_title );
		} elseif ( is_page() || is_single() ) {
			the_title();
		} elseif ( is_category() ) {
			single_cat_title();
		} elseif ( is_archive() ) {
			the_archive_title();
		} elseif ( is_search() ) {
			esc_html_e( 'Search result for: “', 'ama' );
			echo get_search_query() . '”';
		} else {
			the_title();
		}
	}

	/**
	 * Social Links
	 **/
	function social_links() {
		$opt = get_option( 'ama_opt' );
		?>
		<?php if ( ! empty( $opt['facebook'] ) ) { ?>
			<li> <a href="<?php echo esc_url( $opt['facebook'] ); ?>"><i class="social_facebook" aria-hidden="true"></i></a> </li>
		<?php } ?>

		<?php if ( ! empty( $opt['twitter'] ) ) { ?>
			<li> <a href="<?php echo esc_url( $opt['twitter'] ); ?>"><i class="social_twitter" aria-hidden="true"></i></a> </li>
		<?php } ?>

		<?php if ( ! empty( $opt['instagram'] ) ) { ?>
			<li> <a href="<?php echo esc_url( $opt['instagram'] ); ?>"><i class="social_instagram" aria-hidden="true"></i></a> </li>
		<?php } ?>

		<?php if ( ! empty( $opt['linkedin'] ) ) { ?>
			<li> <a href="<?php echo esc_url( $opt['linkedin'] ); ?>"><i class="social_linkedin" aria-hidden="true"></i></a> </li>
		<?php } ?>

		<?php if ( ! empty( $opt['youtube'] ) ) { ?>
			<li> <a href="<?php echo esc_url( $opt['youtube'] ); ?>"><i class="social_youtube" aria-hidden="true"></i></a> </li>
		<?php } ?>

		<?php if ( ! empty( $opt['github'] ) ) { ?>
			<li> <a href="<?php echo esc_url( $opt['github'] ); ?>"><i class="social_github" aria-hidden="true"></i></a> </li>
		<?php } ?>

		<?php if ( ! empty( $opt['dribbble'] ) ) { ?>
			<li> <a href="<?php echo esc_url( $opt['dribbble'] ); ?>"><i class="social_dribbble" aria-hidden="true"></i></a> </li>
			<?php
		}
	}

	/** Render Meta CSS value
	 *
	 * @param $handle
	 * @param $css_items
	 */
	function meta_css_render( $handle, $css_items ) {
		$dynamic_css = '';
		$opt         = get_option( 'ama_opt' );

		$change_types = function_exists( 'get_field' ) ? get_field( 'change_types', 'option' ) : '';

		if ( function_exists( 'get_field' ) ) {
			$keys = array_keys( $css_items );
			for ( $i = 0; $i < count( $css_items ); $i++ ) {
				$split_id   = explode( '__', $keys[ $i ] );
				$meta_id    = $split_id[0];
				$append     = ! empty( $split_id[1] ) ? $split_id[1] : '';
				$meta_value = get_field( $meta_id );
				if ( ! empty( $meta_value ) ) {
					$css_i = 1;
					foreach ( $css_items[ $keys[ $i ] ] as $property => $selector ) {
						$css_output   = "$selector {";
						$css_output  .= "$property: $meta_value$append;";
						$css_output  .= '}';
						$dynamic_css .= $css_output;
						$css_i++;
					}
				}
			}
		}

		if ( ! empty( $opt['custom_css'] ) ) {
			$dynamic_css .= $opt['custom_css'];
		}

		if ( ! empty( $change_types ) ) {
			foreach ( $change_types as $change ) {
				$change_type_class  = $change['type'] ? ama_get_slug( $change['type'] ) : '';
				$changelog_bg_color = ! empty( $change['background_color'] ) ? "background: {$change['background_color']};" : '';
				$changelog_color    = ! empty( $change['font_color'] ) ? "color: {$change['font_color']};" : '';
				if ( ! empty( $changelog_color ) || ! empty( $changelog_bg_color ) ) {
					$dynamic_css .= ".changelog_content span.$change_type_class { $changelog_bg_color $changelog_color }";
				}
			}
		}

		wp_add_inline_style( $handle, $dynamic_css );
	}

	 /**
	  * Pagination
	  **/
	function pagination() {
		the_posts_pagination(
			array(
				'screen_reader_text' => ' ',
				'prev_text'          => '<i class="arrow_carrot-left"></i>',
				'next_text'          => '<i class="arrow_carrot-right"></i>',
			)
		);
	}

	/**
	 * Day link to archive page
	 **/
	function day_link() {
		$archive_year  = get_the_time( 'Y' );
		$archive_month = get_the_time( 'm' );
		$archive_day   = get_the_time( 'd' );
		echo get_day_link( $archive_year, $archive_month, $archive_day );
	}

	/**
	 * Post's excerpt text
	 *
	 * @param $settings_key
	 * @param bool         $echo
	 *
	 * @return string
	 **/
	function excerpt( $settings_key, $echo = true ) {
		$opt = get_option( 'ama_opt' );
		$excerpt_limit   = ! empty( $opt[ $settings_key ] ) ? $opt[ $settings_key ] : 40;
		$post_excerpt = get_the_excerpt();
		$excerpt      = ( strlen( trim( $post_excerpt ) ) != 0 ) ? wp_trim_words( get_the_excerpt(), $excerpt_limit, '' ) : wp_trim_words( get_the_content(), $excerpt_limit, '' );

        if ( $echo == true ) {
			echo wp_kses_post( wpautop( $excerpt ) );
		} else {
			return wp_kses_post( wpautop( $excerpt ) );
		}
	}

	/**
	 * Post author avatar
	 **/
	function post_author_avatar( $size = 50, $default = '', $alt = '', $args = null ) {
		$post_author_id = get_post_field( 'post_author', get_the_ID() );
		echo get_avatar( $post_author_id, $size, $default, $alt, $args );
	}

	/**
	 * Get the first category name
	 *
	 * @param string $term
	 */
	function first_category( $term = 'category' ) {
		$cats = get_the_terms( get_the_ID(), $term );
		$cat  = is_array( $cats ) ? $cats[0]->name : '';
		echo esc_html( $cat );
	}

	/**
	 * Get the first category link
	 *
	 * @param string $term
	 */
	function first_category_link( $term = 'category' ) {
		$cats = get_the_terms( get_the_ID(), $term );
		$cat  = is_array( $cats ) ? get_category_link( $cats[0]->term_id ) : '';
		echo esc_url( $cat );
	}

	/**
	 * Limit letter
	 *
	 * @param $string
	 * @param $limit_length
	 * @param string       $suffix
	 */
	function limit_letter( $string, $limit_length, $suffix = '...' ) {
		if ( strlen( $string ) > $limit_length ) {
			echo strip_shortcodes( substr( $string, 0, $limit_length ) . $suffix );
		} else {
			echo strip_shortcodes( esc_html( $string ) );
		}
	}

	/**
	 * Image from Theme Settings
	 *
	 * @param $settins_key
	 * @param string      $class
	 * @param string      $alt
	 */
	function image_from_settings( $settings_key = '', $class = '', $alt = '' ) {
		$opt        = get_option( 'ama_opt' );
		$page_image = function_exists( 'get_field' ) ? get_field( $settings_key ) : '';
		$sett_image = ! empty( $opt[ $settings_key ] ) ? $opt[ $settings_key ] : '';
		$image      = $page_image == '' ? $sett_image : $page_image;
		if ( ! empty( $image['id'] ) ) {
			echo wp_get_attachment_image( $image['id'], 'full', '', array( 'class' => $class ) );
		} elseif ( ! empty( $image['url'] ) && empty( $image['id'] ) ) {
			$class = ! empty( $class ) ? "class='$class'" : '';
			echo "<img src='{$image['url']}' $class alt='$alt'>";
		}
	}

	/**
	 * Render the Navbar classes based on conditions
	 */
	function navbar_type() {
		$opt               = get_option( 'ama_opt' );
		$banner_preset     = function_exists( 'get_field' ) ? get_field( 'banner_preset' ) : '';
		$search_banner_opt = ! empty( $opt['select_search_banner'] ) ? $opt['select_search_banner'] : 'aesthetic';
		$search_banner     = ! empty( $banner_preset ) && $banner_preset != 'default' ? $banner_preset : $search_banner_opt;
		if ( is_singular( 'post' ) || $search_banner == 'aesthetic' && is_home() || $search_banner == 'aesthetic' && in_array( 'bbpress', get_body_class() ) ) {
			$header_type = 'white';
		} else {
			$header_type = function_exists( 'get_field' ) ? get_field( 'ama_header_type' ) : '';
			if ( ! isset( $header_type ) || $header_type == '' ) {
				$header_type = 'black';
			}
		}
		$nav_classes = $header_type == 'white' ? ' menu_purple' : ' dark_menu';
		echo esc_html( $nav_classes );
	}
}

/**
 * Instance of ama_helper class
 */
function ama_helper() {
	return Ama_helper::instance();
}
