<?php
/**
 * Register Google fonts.
 *
 * @return string Google fonts URL for the theme.
 */

function ama_fonts_url() {
	$fonts_url = '';
	$fonts     = [];
	$subsets   = '';

	/* Translators: Translate on to off if following font is not fully compatible with your language */
	if ( 'off' !== esc_html_x( 'on', 'Roboto font: on or off', 'ama' ) ) {
		$fonts[] = 'Roboto:wght@300;400;500;600;700';
	}

	$is_ssl = is_ssl() ? 'https' : 'http';

	if ( $fonts ) {
		$fonts_url = add_query_arg(
			[
				'family'  => implode( '&family=', $fonts ),
				'display' => urlencode( $subsets ),
			],
			"$is_ssl://fonts.googleapis.com/css2"
		);
	}

	return $fonts_url;
}

/**
 * Enqueue site scripts and styles
 */
function ama_scripts() {
	$opt = get_option( 'ama_opt' );

	/**
	 * Registering site's scripts and styles
	 */
    wp_register_style( 'ama-dark-mode', AMA_DIR_CSS . '/dark-mode.css' );



	wp_enqueue_style( 'ama-fonts', ama_fonts_url(), [], null );
	wp_enqueue_style( 'bootstrap', AMA_DIR_VEND . '/bootstrap/css/bootstrap.min.css' );
	wp_enqueue_style( 'pretty-checkbox', AMA_DIR_CSS . '/pretty-checkbox.min.css' );
	wp_enqueue_style( 'slick', AMA_DIR_VEND . '/slick/slick.css' );
	wp_enqueue_style( 'slick-theme', AMA_DIR_VEND . '/slick/slick-theme.css' );
	wp_enqueue_style( 'elegant-icons', AMA_DIR_VEND . '/elagent-icon/style.css' );
	wp_enqueue_style( 'nice-select', AMA_DIR_VEND . '/niceselectpicker/nice-select.css' );
	wp_enqueue_style( 'animate', AMA_DIR_VEND . '/animation/animate.css' );
	wp_enqueue_style( 'dropzone', AMA_DIR_VEND . '/dropzone/dropzone.css' );
	wp_enqueue_style( 'magnific-popup', AMA_DIR_VEND . '/magnify-pop/magnific-popup.css' );
	wp_enqueue_style( 'line-awesome', AMA_DIR_VEND . '/line-awesome/css/line-awesome.min.css' );
	wp_enqueue_style( 'bootstrap-icons', AMA_DIR_VEND . '/bootstrap-icons/bootstrap-icons.css' );
	wp_enqueue_style( 'ama-main', AMA_DIR_CSS . '/main.css' );
	wp_enqueue_style( 'ama-responsive', AMA_DIR_CSS . '/responsive.css' );
	wp_enqueue_style( 'ama-root', get_stylesheet_uri() );

	$css_output = [
		'menu_item_color'            => [
			'color' => '.navbar .menu > .nav-item > .nav-link',
		],
		'banner_background_color'    => [
			'background-color' => '.aj-titleabar-container',
		],
		'banner_text_color'          => [
			'color' => '.doc_banner_content .aj-titlebar h1, .doc_banner_content .aj-titlebar p',
		],
		'footer_pt__px'              => [
			'padding-top' => '.footer_area',
		],
		'footer_pr__px'              => [
			'padding-right' => '.footer_area',
		],
		'footer_pb__px'              => [
			'padding-bottom' => '.footer_area',
		],
		'footer_pl__px'              => [
			'padding-left' => '.footer_area',
		],
		'btn_background_color'       => [
			'background' => '.nav_btn',
		],
		'footer_background_color'    => [
			'background-color' => '.doc_footer_top',
		],

		/**
		 * Action Button
		 */
		'btn_border_radius'          => [
			'border-radius' => '.right-nav .nav_btn.tp_btn',
		],
		'btn_text_color'             => [
			'color' => '.right-nav .nav_btn',
		],
		'btn_border_color'           => [
			'border-color' => '.right-nav .nav_btn',
		],
		'hover_btn_background_color' => [
			'background' => '.right-nav .nav_btn:hover',
		],
		'hover_btn_text_color'       => [
			'color' => '.right-nav .nav_btn:hover',
		],
		'hover_btn_border_color'     => [
			'border-color' => '.right-nav .nav_btn:hover',
		],

		/**
		 * Page Settings
		 */
		'page_padding_top__px'       => [
			'padding-top' => '.page_wrapper',
		],
		'page_padding_right__px'     => [
			'padding-right' => '.page_wrapper',
		],
		'page_padding_bottom__px'    => [
			'padding-bottom' => '.page_wrapper',
		],
		'page_padding_left__px'      => [
			'padding-left' => '.page_wrapper',
		],
	];

	ama_helper()->meta_css_render( 'ama-root', $css_output );

	/**
	 * Register and enqueue theme script files
	 */
    wp_register_script( 'ama-dark-mode', AMA_DIR_JS . '/dark-mode.js', array( 'jquery' ), '1.0.0', true );
	wp_register_script( 'preloader', AMA_DIR_JS . '/pre-loader.js', [ 'jquery' ], '1.0', true );
	wp_register_script( 'ama-forum', AMA_DIR_JS . '/forum.js', [ 'jquery' ], '1.0.0', true );

	/**
	 * JavaScripts
	 */
	wp_enqueue_script( 'bootstrap-bundle', AMA_DIR_VEND . '/bootstrap/js/bootstrap.bundle.min.js', [ 'jquery' ], '5.0.0-beta3', true );
	wp_enqueue_script( 'slick', AMA_DIR_VEND . '/slick/slick.min.js', [ 'jquery' ], '1.0', true );
	wp_enqueue_script( 'parallax-scroll', AMA_DIR_JS . '/jquery.parallax-scroll.js', [ 'jquery' ], '1.0', true );
	wp_enqueue_script( 'nice-select', AMA_DIR_VEND . '/niceselectpicker/jquery.nice-select.min.js', [ 'jquery' ], '1.0', true );
	wp_enqueue_script( 'wow', AMA_DIR_VEND . '/wow/wow.min.js', [ 'jquery' ], '1.1.3', true );
	wp_enqueue_script( 'custom-scrollbar', AMA_DIR_VEND . '/mcustomscrollbar/jquery.mCustomScrollbar.concat.min.js', [ 'jquery' ], '3.1.13', true );
	wp_enqueue_script( 'waypoint', AMA_DIR_VEND . '/counterup/jquery.waypoints.min.js', [ 'jquery' ], '4.0.1', true );
	wp_enqueue_script( 'counter-up', AMA_DIR_VEND . '/counterup/jquery.counterup.min.js', [ 'jquery' ], '4.0.1', true );
	wp_enqueue_script( 'parallaxie', AMA_DIR_JS . '/parallaxie.js', [ 'jquery' ], '1.0', true );
	wp_enqueue_script( 'magnific-popup', AMA_DIR_VEND . '/magnify-pop/jquery.magnific-popup.min.js', [ 'jquery' ], '1.0', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	wp_enqueue_script( 'ama-main', AMA_DIR_JS . '/main.js', [ 'jquery' ], '1.0', true );

	$ajax_url = admin_url( 'admin-ajax.php' );

	if ( in_array( 'bbpress', get_body_class() ) && class_exists( 'bbPress' ) ) {
		wp_enqueue_script( 'ama-forum' );
	}

	// Hero Search script.
	wp_localize_script(
		'jquery',
		'ama_local_object',
		[
			'ajaxurl' => $ajax_url,
		]
	);

	// Forum Filter Script.
	global $wp_query;
	$localized_settings = [
		'ajax_url'     => admin_url( 'admin-ajax.php' ),
		'ama_nonce'    => wp_create_nonce( 'ama-nonce' ),
		'ama_parent'   => get_queried_object_id(),
		'posts'        => json_encode( $wp_query->query_vars ), // everything about your loop is here
		'current_page' => get_query_var( 'paged' ) ? get_query_var( 'paged' ) : 1,
		'max_page'     => $wp_query->max_num_pages,
		'first_page'   => get_pagenum_link( 1 ),
	];

	wp_localize_script(
		'ama-forum',
		'AmaForum',
		$localized_settings
	);
}

add_action( 'wp_enqueue_scripts', 'ama_scripts' );

// Admin dashboard style and scripts.
add_action(
	'admin_enqueue_scripts',
	function() {
		global $pagenow;

		if ( $pagenow == 'admin.php' ) {
			wp_enqueue_style( 'elegant-icon', AMA_DIR_VEND . '/elagent-icon/style.css' );
			wp_enqueue_style( 'ama-admin-dashboard', AMA_DIR_CSS . '/admin-dashboard.min.css' );
		}
	}
);
