<?php
// Theme settings options
$opt = get_option( 'ama_opt' );

// Image sizes
add_image_size( 'ama_370x360', 370, 360, true ); // Posts carousel thumbnail
add_image_size( 'ama_375x220', 375, 220, true ); // Post grid thumbnail
add_image_size( 'ama_770x400', 770, 400, true ); // Blog post list format
add_image_size( 'ama_370x220', 370, 220, true ); // Blog post grid format
add_image_size( 'ama_370x236', 370, 236, true ); // Blog post grid format
add_image_size( 'ama_370x200', 370, 200, true ); // Related post thumbnail
add_image_size( 'ama_670x450', 670, 450, true ); // Blog Category Page Sticky post thumbnail
add_image_size( 'ama_210x200', 210, 200, true ); // Forum User Profile Image
add_image_size( 'ama_18x18', 18, 18, true ); // Forum post topic category thumbnail
add_image_size( 'ama_20x20', 20, 20, true ); // Forum post topic category thumbnail

// add category nick names in body and post class
function ama_post_class( $classes ) {
	global $post;
	if ( ! has_post_thumbnail() ) {
		$classes[] = 'no-post-thumbnail';
	}
	if ( is_sticky() && ! in_array( 'sticky', $classes ) ) {
		$classes[] = 'sticky';
	}

	return $classes;
}

add_filter( 'post_class', 'ama_post_class' );

/**
 * Body classes
 */
add_filter('body_class', function ( $classes ) {
    $has_menu      = has_nav_menu( 'main_menu' ) ? '' : 'has_not_menu';

    if ( ama_opt('is_dark_default') == '1' ) {
        wp_enqueue_style( 'ama-dark-mode' );
        $classes[] = 'body_dark';
    }

    $classes[] = $has_menu;

    return $classes;
});

/**
 * Show post excerpt by default
 *
 * @param $user_login
 * @param $user
 */
function ama_show_post_excerpt( $user_login, $user ) {
	$unchecked = get_user_meta( $user->ID, 'metaboxhidden_post', true );
	$key       = is_array( $unchecked ) ? array_search( 'postexcerpt', $unchecked ) : false;
	if ( false !== $key ) {
		array_splice( $unchecked, $key, 1 );
		update_user_meta( $user->ID, 'metaboxhidden_post', $unchecked );
	}
}

add_action( 'wp_login', 'ama_show_post_excerpt', 10, 2 );

/**
 * Add a pingback url auto-discovery header for singularly identifiable articles.
 */
function ama_pingback_header() {
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
	}
}

add_action( 'wp_head', 'ama_pingback_header' );

// Move the comment field to bottom.
add_filter(
	'comment_form_fields',
	function ( $fields ) {
		$comment_field = $fields['comment'];
		unset( $fields['comment'] );
		$fields['comment'] = $comment_field;

		return $fields;
	}
);

// Remove WordPress admin bar default CSS.
add_action(
	'get_header',
	function () {
		remove_action( 'wp_head', '_admin_bar_bump_cb' );
	}
);

// Elementor post type support.
function ama_add_cpt_support() {

	// if exists, assign to $cpt_support var.
	$cpt_support = get_option( 'elementor_cpt_support' );

	// check if option DOESN'T exist in db.
	if ( ! $cpt_support ) {
		$cpt_support = array( 'page', 'post', 'docs' ); // create array of our default supported post types.
		update_option( 'elementor_cpt_support', $cpt_support ); // write it to the database.
	} // if it DOES exist, but header is NOT defined.
	elseif ( ! in_array( 'docs', $cpt_support ) ) {
		$cpt_support[] = 'docs'; // append to array
		update_option( 'elementor_cpt_support', $cpt_support ); // update database
	}

	// otherwise do nothing, portfolio already exists in elementor_cpt_support option
}

add_action( 'after_switch_theme', 'ama_add_cpt_support' );

/**
 * Slug re-write
 */
if ( ! empty( $opt['doc_slug'] ) ) {
	add_filter( 'register_post_type_args', 'ama_register_post_type_args', 10, 2 );
	function ama_register_post_type_args( $args, $post_type ) {
		$opt = get_option( 'ama_opt' );
		if ( 'docs' === $post_type ) {
			$args['rewrite']['slug'] = $opt['doc_slug'];
		}

		return $args;
	}
}

// Color Picker Issue solution
if ( is_admin() ) {
	add_action( 'wp_default_scripts', 'ama_default_custom_scripts' );
	function ama_default_custom_scripts( $scripts ) {
		$scripts->add( 'wp-color-picker', '/wp-admin/js/color-picker.js', array( 'iris' ), false, 1 );
		did_action( 'init' ) && $scripts->localize(
			'wp-color-picker',
			'wpColorPickerL10n',
			array(
				'clear'            => esc_html__( 'Clear', 'ama' ),
				'clearAriaLabel'   => esc_html__( 'Clear color', 'ama' ),
				'defaultString'    => esc_html__( 'Default', 'ama' ),
				'defaultAriaLabel' => esc_html__( 'Select default color', 'ama' ),
				'pick'             => esc_html__( 'Select Color', 'ama' ),
				'defaultLabel'     => esc_html__( 'Color value', 'ama' ),
			)
		);
	}
}

/**
 * Saving automatically the ACF group fields json files
 */
add_filter(
	'acf/settings/save_json',
	function ( $path ) {

		// update path
		$path = get_stylesheet_directory() . '/inc/acf-json';

		// return
		return $path;
	}
);

/**
 * Loading the saved ACF fields
 */
add_filter(
	'acf/settings/load_json',
	function ( $paths ) {
		// append path
		$paths[] = get_stylesheet_directory() . '/inc/acf-json';

		// return
		return $paths;
	}
);

/**
 * Turn on the WordPress visual editor for bbPress
 *
 * @param array $args
 *
 * @return array|mixed
 */
function ama_bbp_enable_visual_editor( $args = array() ) {
	$args['tinymce'] = true;

	return $args;
}

add_filter( 'bbp_after_get_the_content_parse_args', 'ama_bbp_enable_visual_editor' );

if ( function_exists( 'acf_add_options_sub_page' ) ) {
	acf_add_options_sub_page(
		array(
			'page_title'  => esc_html__( 'Changelogs Settings', 'ama' ),
			'menu_title'  => esc_html__( 'Settings', 'ama' ),
			'parent_slug' => 'edit.php?post_type=changelog',
		)
	);
}

/**
 * bbPress forum configurations
 */
if ( class_exists( 'bbPress' ) ) {
	require get_template_directory() . '/inc/bbpress-config.php';
}
