<?php
/**
 * Custom functions that act independently of the theme templates
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package ama
 */

/**
 * Get theme option
 *
 * @param $option
 * @param $default
 *
 * @return mixed|string
 */
function ama_opt ($option = '', $default = '')
{
	$opt = get_option('ama_opt');

	return !empty($opt[ $option ]) ? $opt[ $option ] : $default;
}

// Search form
function ama_search_form( $is_button = true ) {
	?>
	<div class="ama-search">
		<form class="form-wrapper" action="<?php echo esc_url( home_url( '/' ) ); ?>" _lpchecked="1">
			<input type="text" id="search" placeholder="<?php esc_attr_e( 'Search ...', 'ama' ); ?>" name="s">
			<button type="submit" class="btn"><i class="fa fa-search"></i></button>
		</form>
		<?php if ( $is_button == true ) : ?>
			<a href="<?php echo esc_url( home_url( '/' ) ); ?>" class="home_btn"> <?php esc_html_e( 'Back to home Page', 'ama' ); ?> </a>
		<?php endif; ?>
	</div>
	<?php
}

// Get comment count text
function ama_comment_count( $post_id ) {
	$comments_number = get_comments_number( $post_id );

	if ( $comments_number == 0 ) {
		$comment_text = esc_html__( 'No Comments', 'ama' );
	} elseif ( $comments_number == 1 ) {
		$comment_text = esc_html__( '1 Comment', 'ama' );
	} elseif ( $comments_number > 1 ) {
		$comment_text = $comments_number . esc_html__( ' Comments', 'ama' );
	}

	echo esc_html( $comment_text );
}

// Get author role
function ama_get_author_role() {
	global $authordata;
	$author_roles = $authordata->roles;
	$author_role  = array_shift( $author_roles );

	return esc_html( $author_role );
}

// Banner Subtitle
function ama_banner_subtitle() {
	$opt = get_option( 'ama_opt' );
	if ( is_home() ) {
		$blog_subtitle = ! empty( $opt['blog_subtitle'] ) ? $opt['blog_subtitle'] : get_bloginfo( 'description' );
		echo esc_html( $blog_subtitle );
	} elseif ( is_page() || is_single() ) {
		if ( has_excerpt() ) {
			while ( have_posts() ) {
				the_post();
				echo nl2br( get_the_excerpt( get_the_ID() ) );
			}
		}
	} elseif ( is_archive() ) {
		echo '';
	}
}

/**
 * Post title array
 */
function ama_get_postTitleArray( $postType = 'post' ) {
	$post_type_query = new WP_Query(
		[
			'post_type'      => $postType,
			'posts_per_page' => - 1,
		]
	);
	// we need the array of posts
	$posts_array = $post_type_query->posts;
	// the key equals the ID, the value is the post_title
	if ( is_array( $posts_array ) ) {
		$post_title_array = wp_list_pluck( $posts_array, 'post_title', 'ID' );
	} else {
		$post_title_array['default'] = esc_html__( 'Default', 'ama' );
	}

	return $post_title_array;
}

/**
 * Get a specific html tag from content
 *
 * @return String a specific HTML tag from the loaded content
 */
function ama_get_html_tag( $tag = 'blockquote', $content = '' ) {
	$dom = new DOMDocument();
	$dom->loadHTML( $content );
	$divs = $dom->getElementsByTagName( $tag );
	$i    = 0;
	foreach ( $divs as $div ) {
		if ( $i == 1 ) {
			break;
		}
		echo "<h4 class='c_head'>{$div->nodeValue}</h4>";
		++ $i;
	}
}

/**
 * Get the page id by page template
 *
 * @param string $template
 *
 * @return int
 */
function ama_get_page_template_id( $template = 'page-job-apply-form.php' ) {
	$pages = get_pages(
		[
			'meta_key'   => '_wp_page_template',
			'meta_value' => $template,
		]
	);
	foreach ( $pages as $page ) {
		$page_id = $page->ID;
	}

	return $page_id;
}

/**
 * Arrow icon left right position
 */
function ama_arrow_left_right() {
	$arrow_icon             = is_rtl() ? 'arrow_left' : 'arrow_right';
	is_404() && $arrow_icon = is_rtl() ? 'arrow_right' : 'arrow_left';

	echo esc_attr( $arrow_icon );
}

/**
 * Search results page's active tab
 */
function ama_is_search_tab_active( $post_type ) {
	if ( isset( $_GET['post_type'] ) && sanitize_text_field( $_GET['post_type'] ) == $post_type ) {
		echo 'active';
	} elseif ( ! isset( $_GET['post_type'] ) && $post_type == 'all' ) {
		echo 'active';
	}
}

/**
 * Ama post breadcrumbs
 */
function ama_post_breadcrumbs() {
	$opt = get_option( 'ama_opt' );
	if ( is_home() ) {
		$title = ! empty( $opt['blog_title'] ) ? $opt['blog_title'] : esc_html__( 'Blog', 'ama' );
	} else {
		$title = get_the_title();
	}
	if ( in_array( 'bbpress', get_body_class() ) ) {
		bbp_breadcrumb(
			[
				'before'         => '<ol class="breadcrumb"> <li class="breadcrumb-item">',
				'sep_before'     => '',
				'sep'            => '</li><li class="breadcrumb-item">',
				'sep_after'      => '',
				'current_before' => '',
				'current_after'  => '',
				'after'          => '</li></ol>',
				'home_text'      => esc_html__( 'Home', 'ama' ),
			]
		);
	} elseif ( in_array( 'type-topic', get_post_class() ) ) {
		bbp_breadcrumb();
	} else {
		?>
		<ol class="breadcrumb">
			<li class="breadcrumb-item">
				<a href="<?php echo esc_url( home_url( '/' ) ); ?>"> <?php esc_html_e( 'Home', 'ama' ); ?> </a>
			</li>
			<?php if ( ! is_archive() && ! is_home() && ! is_search() ) : ?>
				<li class="breadcrumb-item">
					<a href="<?php echo get_post_type_archive_link( get_post_type( get_the_ID() ) ); ?>">
						<?php echo ucwords( get_post_type( get_the_ID() ) ); ?>
					</a>
				</li>
			<?php endif; ?>

			<?php if ( is_search() ) : ?>
				<li class="breadcrumb-item">
					<a href="<?php echo esc_url( home_url( '/?s=' ) ) . esc_attr( get_search_query() ); ?>">
						<?php echo esc_html( 'Search result for "' ) . get_search_query() . '"'; ?>
					</a>
				</li>
			<?php endif; ?>

			<?php if ( is_archive() && ! is_home() ) : ?>
				<li class="breadcrumb-item active">
					<?php echo ucwords( get_post_type() ); ?>
				</li>
			<?php endif; ?>

			<?php if ( is_home() ) : ?>
				<li class="breadcrumb-item active">
					<?php esc_html_e( 'Blog', 'ama' ); ?>
				</li>
			<?php endif; ?>

			<?php if ( is_single() ) : ?>
				<li class="breadcrumb-item active" aria-current="page">
					<?php echo esc_html( $title ); ?>
				</li>
			<?php endif; ?>
		</ol>
		<?php
	}
}


/**
 * Ama post breadcrumbs
 */
function ama_content_breadcrumb() {
	$opt = get_option( 'ama_opt' );
	if ( is_home() ) {
		$title = ! empty( $opt['blog_title'] ) ? $opt['blog_title'] : esc_html__( 'Blog', 'ama' );
	} else {
		$title = get_the_title();
	}
	if ( in_array( 'bbpress', get_body_class() ) ) {
		bbp_breadcrumb(
			[
				'before'         => '<ol class="breadcrumb"> <li class="breadcrumb-item">',
				'sep_before'     => '',
				'sep'            => '</li><li class="breadcrumb-item">',
				'sep_after'      => '',
				'current_before' => '',
				'current_after'  => '',
				'after'          => '</li></ol>',
				'home_text'      => esc_html__( 'Home', 'ama' ),
			]
		);
	} elseif ( in_array( 'type-topic', get_post_class() ) ) {
		bbp_breadcrumb();
	} else {
		?>
		<ol class="breadcrumb">
			<li class="breadcrumb-item">
				<a href="<?php echo esc_url( home_url( '/' ) ); ?>"> <?php esc_html_e( 'Home', 'ama' ); ?> </a>
			</li>
			<li class="breadcrumb-item">
				<a href="<?php echo get_post_type_archive_link( get_post_type( get_the_ID() ) ); ?>">
					<?php echo ucwords( get_post_type( get_the_ID() ) ); ?>
				</a>
			</li>
			<?php if ( ! is_archive() && ! is_home() && ! is_search() ) : ?>
				<li class="breadcrumb-item">
					<a href="<?php echo get_post_type_archive_link( get_post_type( get_the_ID() ) ); ?>">
						<?php echo ucwords( get_post_type( get_the_ID() ) ); ?>
					</a>
				</li>
			<?php endif; ?>

			<?php if ( is_archive() && ! is_home() ) : ?>
				<li class="breadcrumb-item active">
					<?php echo ucwords( get_post_type() ); ?>
				</li>
			<?php endif; ?>

			<?php if ( is_home() ) : ?>
				<li class="breadcrumb-item active">
					<?php esc_html_e( 'Blog', 'ama' ); ?>
				</li>
			<?php endif; ?>

			<?php if ( is_single() ) : ?>
				<li class="breadcrumb-item active" aria-current="page">
					<?php echo esc_html( $title ); ?>
				</li>
			<?php endif; ?>
		</ol>
		<?php
	}
}

/**
 * Estimated reading time
 **/
function ama_reading_time() {
	$content      = get_post_field( 'post_content', get_the_ID() );
	$word_count   = str_word_count( strip_tags( $content ) );
	$reading_time = ceil( $word_count / 200 );

	if ( $reading_time == 1 ) {
		$timer = esc_html__( ' minute read', 'ama' );
	} else {
		$timer = esc_html__( ' minutes read', 'ama' );
	}

	$total_reading_time = $reading_time . $timer;
	echo esc_html( $total_reading_time );
}

/**
 * Is show/hide search banner
 */
function ama_is_search_banner() {

	$opt                   = get_option( 'ama_opt' );
	$is_search_banner_opt  = $opt['is_search_banner'] ?? '1';
	$is_search_banner_page = function_exists( 'get_field' ) ? get_field( 'is_search_banner' ) : '';
	$is_search_banner      = isset( $is_search_banner_page ) && $is_search_banner_page != 'default' ? $is_search_banner_page : $is_search_banner_opt;

	if ( ! isset( $is_search_banner ) || $is_search_banner == '0' ) {
		$is_search_banner = '1';
	}

	if ( is_home() || in_array( 'bbpress', get_body_class() ) || is_search() ) {
		if ( ! isset( $is_search_banner_opt ) ) {
			$is_search_banner = '1';
		} elseif ( isset( $is_search_banner_opt ) ) {
			$is_search_banner = $is_search_banner_opt;
		}
	}

	$in_array_classes = in_array( 'bbp-shortcode', get_body_class() ) || ama_forum_user_profile();

	if ( $in_array_classes || is_page() || is_archive() || is_archive( 'docs' ) || is_singular( [ 'post', 'reply', 'docs' ] ) || is_404() || is_category() || is_tag() || is_author() ) {
		$is_search_banner = '';
	}

	if ( class_exists( 'bbPress' ) ) {
		if ( bbp_is_forum_archive() || bbp_is_topic_archive() || bbp_is_search() ) {
			$is_search_banner = '1';
		}
	}

	return $is_search_banner;
}

/**
 * Search banner
 */
function ama_search_banner() {
	$opt                = get_option( 'ama_opt' );
	$search_banner_page = function_exists( 'get_field' ) ? get_field( 'banner_preset' ) : '';
	$search_banner_opt  = ! empty( $opt['select_search_banner'] ) ? $opt['select_search_banner'] : 'aesthetic';

	return ! empty( $search_banner_page ) && $search_banner_page != 'default' ? $search_banner_page : $search_banner_opt;
}

/**
 * Check If the Page is Forum user profile page
 */
function ama_forum_user_profile() {
	if ( in_array( 'bbp-user-page', get_body_class() ) || in_array( 'bbp-user-edit', get_body_class() ) ) {
		return true;
	}
}

/**
 * Modified Date
 */
function ama_modified_date() {
	$modified_date = '';

	$recent_posts = wp_get_recent_posts(
		[
			'numberposts' => 1, // Number of recent posts thumbnails to display
			'post_status' => 'publish', // Show only the published posts
		]
	);

	foreach ( $recent_posts as $recent_post ) {
		$modified_date = get_the_time( get_option( 'date_format' ), $recent_post['ID'] );
	}

	if ( is_home() ) {
		echo esc_html( $modified_date );
	} else {
		the_modified_date( get_option( 'date_format' ) );
	}
}

/**
 * Allowed HTML for wp_kses function
 *
 * @return array
 */
function ama_allowed_html() {
	return [
		'a'      => [
			'class'  => [],
			'href'   => true,
			'rel'    => true,
			'rev'    => true,
			'name'   => true,
			'target' => true,
		],

		'br'     => [],

		'p'      => [
			'class' => [],
		],

		'strong' => [],
		'div'    => [
			'style' => [],
			'class' => [],
		],

		'img'    => [
			'class'  => [],
			'src'    => [],
			'srcset' => [],
			'alt'    => [],
		],
	];
}

/**
 * Decode Ama
 */
function ama_decode_du( $str ) {
	$str = str_replace( 'cZ5^9o#!', 'wordpress-theme.spider-themes.net', $str );
	$str = str_replace( 'aI7!8B4H', 'resources', $str );
	$str = str_replace( '^93|3d@', 'https', $str );
	$str = str_replace( 't7Cg*^n0', 'ama', $str );
	$str = str_replace( '3O7%jfGc', '.zip', $str );
}


/**
 * @param $page_title_name
 * @return int|string|void
 * Get page title id
 */
function ama_get_page_title ( $page_title_name = '' ) {
    $args = array(
        'post_type' => 'page',
        'posts_per_page' => -1,
        'post_status' => 'publish'
    );

    $pages = get_posts($args);

    if (!empty($pages)) {
        $title_name_id = '';
        foreach ( $pages as $page ) {
            if ($page->post_title == $page_title_name) {
                $title_name_id = $page->ID;
            }
        }

        return $title_name_id;
    }

}